@@ -1,15 +1,13 @@
 """Fine-grained control of reading data files."""
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
-import functools
 import os
+from typing import Any
 from xml.etree import ElementTree
 
-from typing import Any
-
 import pyvista
-from pyvista.utilities import wrap, get_ext
 from pyvista import _vtk
+from pyvista.utilities import get_ext, wrap
 
 
 def get_reader(filename):
@@ -103,7 +101,7 @@ def get_reader(filename):
 
 class BaseReader:
     """The Base Reader class.
-    
+
     The base functionality includes reading data from a file,
     and allowing access to the underlying vtk reader. See
     :func:`pyvista.get_reader` for an example using
@@ -193,13 +191,13 @@ class PointCellDataSelection:
     >>> mesh = reader.read()  # MultiBlock mesh
     >>> mesh[0].array_names
     ['U']
-    
+
     """
 
     @property
     def number_point_arrays(self):
         """Return the number of point arrays.
-        
+
         Returns
         -------
         int
@@ -210,7 +208,7 @@ class PointCellDataSelection:
     @property
     def point_array_names(self):
         """Return the list of all point array names.
-        
+
         Returns
         -------
         list[int]
@@ -271,7 +269,7 @@ class PointCellDataSelection:
     @property
     def all_point_arrays_status(self):
         """Return the status of all point arrays.
-        
+
         Returns
         -------
         dict[str, bool]
@@ -282,7 +280,7 @@ class PointCellDataSelection:
     @property
     def number_cell_arrays(self):
         """Return the number of cell arrays.
-        
+
         Returns
         -------
         int
@@ -293,7 +291,7 @@ class PointCellDataSelection:
     @property
     def cell_array_names(self):
         """Return the list of all cell array names.
-        
+
         Returns
         -------
         list[str]
@@ -354,7 +352,7 @@ class PointCellDataSelection:
     @property
     def all_cell_arrays_status(self):
         """Return the status of all cell arrays.
-        
+
         Returns
         -------
         dict[str, bool]
@@ -370,7 +368,7 @@ class TimeReader(ABC):
     @abstractmethod
     def number_time_points(self):
         """Return number of time points or iterations available to read.
-        
+
         Returns
         -------
         int
@@ -380,7 +378,7 @@ class TimeReader(ABC):
     @abstractmethod
     def time_point_value(self, time_point):
         """Value of time point or iteration by index.
-        
+
         Parameters
         ----------
         time_point: int
@@ -448,10 +446,10 @@ class XMLPImageDataReader(BaseReader, PointCellDataSelection):
 
     _class_reader = _vtk.vtkXMLPImageDataReader
 
-    
+
 class XMLRectilinearGridReader(BaseReader, PointCellDataSelection):
     """XML RectilinearGrid Reader for .vtr files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -478,7 +476,7 @@ class XMLPRectilinearGridReader(BaseReader, PointCellDataSelection):
 
 class XMLUnstructuredGridReader(BaseReader, PointCellDataSelection):
     """XML UnstructuredGrid Reader for .vtu files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -504,7 +502,7 @@ class XMLPUnstructuredGridReader(BaseReader, PointCellDataSelection):
 
 class XMLPolyDataReader(BaseReader, PointCellDataSelection):
     """XML PolyData Reader for .vtp files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -526,7 +524,7 @@ class XMLPolyDataReader(BaseReader, PointCellDataSelection):
 
 class XMLStructuredGridReader(BaseReader, PointCellDataSelection):
     """XML StructuredGrid Reader for .vts files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -551,7 +549,7 @@ class XMLMultiBlockDataReader(BaseReader, PointCellDataSelection):
 # skip pydocstyle D102 check since docstring is taken from TimeReader
 class EnSightReader(BaseReader, PointCellDataSelection, TimeReader):
     """EnSight Reader for .case files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -561,7 +559,7 @@ class EnSightReader(BaseReader, PointCellDataSelection, TimeReader):
     'cylinder_Re35.case'
     >>> reader = pyvista.get_reader(filename)
     >>> mesh = reader.read()
-    >>> mesh.plot(scalars="velocity", component=1, clim=[-20, 20], 
+    >>> mesh.plot(scalars="velocity", component=1, clim=[-20, 20],
     ...           cpos='xy', cmap='RdBu', show_scalar_bar=False)
 
     """
@@ -604,6 +602,16 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
 
     _class_reader = _vtk.vtkOpenFOAMReader
 
+    def __init__(self, filename):
+        """Initialize OpenFOAMReader.
+
+        By default, pyvista enables all patch arrays.  This is a deviation
+        from the vtk default.
+
+        """
+        super().__init__(filename)
+        self.enable_all_patch_arrays()
+
     @property
     def number_time_points(self):  # noqa: D102
         return self.reader.GetTimeValues().GetNumberOfValues()
@@ -613,7 +621,12 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
 
     @property
     def active_time_value(self):  # noqa: D102
-        raise NotImplementedError("vtkOpenFOAMReader does not yet support this")
+        try:
+            value = self.reader.GetTimeValue()
+        except AttributeError as err:  # pragma: no cover
+            raise AttributeError("Inspecting active time value only supported "
+                      "for vtk versions >9.1.0") from err
+        return value
 
     def set_active_time_value(self, time_value):  # noqa: D102
         if time_value not in self.time_values:
@@ -625,10 +638,205 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
     def set_active_time_point(self, time_point):  # noqa: D102
         self.reader.SetTimeValue(self.time_point_value(time_point))
 
+    @property
+    def cell_to_point_creation(self):
+        """Whether cell data is translated to point data when read.
+
+        Returns
+        -------
+        bool
+            If ``True``, translate cell data to point data.
+
+        Warnings
+        --------
+        When ``True``, cell and point data arrays will have
+        duplicate names.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.cell_to_point_creation = False
+        >>> reader.cell_to_point_creation
+        False
+
+        """
+        return bool(self.reader.GetCreateCellToPoint())
+
+    @cell_to_point_creation.setter
+    def cell_to_point_creation(self, value):
+        if value:
+            self.reader.CreateCellToPointOn()
+        else:
+            self.reader.CreateCellToPointOff()
+
+    @property
+    def number_patch_arrays(self):
+        """Return number of patch arrays in dataset.
+        
+        Returns
+        -------
+        int
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.number_patch_arrays
+        4
+        
+        """
+        return self.reader.GetNumberOfPatchArrays()
+
+    @property
+    def patch_array_names(self):
+        """Names of patch arrays in a list.
+        
+        Returns
+        -------
+        list[str]
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.patch_array_names
+        ['internalMesh', 'patch/movingWall', 'patch/fixedWalls', 'patch/frontAndBack']
+
+        """
+        return [self.reader.GetPatchArrayName(i) for i in range(self.number_patch_arrays)]
+
+    def enable_patch_array(self, name):
+        """Enable reading of patch array.
+
+        Parameters
+        ----------
+        name : str
+            Which patch array to enable.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.enable_patch_array("patch/movingWall")
+        >>> reader.patch_array_status("patch/movingWall")
+        True
+
+        """
+        self.reader.SetPatchArrayStatus(name, 1)
+
+    def disable_patch_array(self, name):
+        """Disable reading of patch array.
+
+        Parameters
+        ----------
+        name : str
+            Which patch array to disable.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.disable_patch_array("internalMesh")
+        >>> reader.patch_array_status("internalMesh")
+        False
+
+        """
+        self.reader.SetPatchArrayStatus(name, 0)
+
+    def patch_array_status(self, name):
+        """Return status of reading patch array.
+
+        Parameters
+        ----------
+        name : str
+            Which patch array to report status.
+        Returns
+        -------
+        bool
+                Whether the patch with the given name is to be read.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.enable_patch_array("patch/movingWall")
+        >>> reader.patch_array_status("patch/movingWall")
+        True
+
+        """
+        return bool(self.reader.GetPatchArrayStatus(name))
+
+    def enable_all_patch_arrays(self):
+        """Enable reading of all patch arrays.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.enable_all_patch_arrays()
+        >>> assert reader.patch_array_status("patch/movingWall")
+        >>> assert reader.patch_array_status("patch/fixedWalls")
+
+        """
+        self.reader.EnableAllPatchArrays()
+    
+    def disable_all_patch_arrays(self):
+        """Disable reading of all patch arrays.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.disable_all_patch_arrays()
+        >>> assert not reader.patch_array_status("patch.movingWall")
+        >>> assert not reader.patch_array_status("internalMesh")
+
+        """
+        self.reader.DisableAllPatchArrays()
+
+    @property
+    def all_patch_arrays_status(self):
+        """Status of reading all patch arrays.
+
+        Returns
+        -------
+        dict[str, bool]
+            dict key is the patch name and the value is whether it will be read.
+
+        Examples
+        --------
+        >>> import pyvista
+        >>> from pyvista import examples
+        >>> filename = examples.download_cavity(load=False)
+        >>> reader = pyvista.OpenFOAMReader(filename)
+        >>> reader.all_patch_arrays_status  #doctest: +NORMALIZE_WHITESPACE
+        {'internalMesh': True, 'patch/movingWall': True, 'patch/fixedWalls': True,
+         'patch/frontAndBack': True}
+
+        """
+        return {name: self.patch_array_status(name) for name in self.patch_array_names}
+
 
 class PLYReader(BaseReader):
     """PLY Reader for reading .ply files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -647,7 +855,7 @@ class PLYReader(BaseReader):
 
 class OBJReader(BaseReader):
     """OBJ Reader for reading .obj files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -666,7 +874,7 @@ class OBJReader(BaseReader):
 
 class STLReader(BaseReader):
     """STL Reader for .stl files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -685,7 +893,13 @@ class STLReader(BaseReader):
 
 class VTKDataSetReader(BaseReader):
     """VTK Data Set Reader for .vtk files.
-    
+
+    Notes
+    -----
+    This reader calls `ReadAllScalarsOn`, `ReadAllColorScalarsOn`,
+    `ReadAllNormalsOn`, `ReadAllTCoordsOn`, `ReadAllVectorsOn`,
+    and `ReadAllFieldsOn` on the underlying `vtkDataSetReader`.
+
     Examples
     --------
     >>> import pyvista
@@ -702,6 +916,18 @@ class VTKDataSetReader(BaseReader):
 
     _class_reader = _vtk.vtkDataSetReader
 
+    def __init__(self, filename):
+        """Initialize VTKDataSetReader with filename."""
+        super().__init__(filename)
+        # Provide consistency with defaults in pyvista.read
+        self.reader.ReadAllScalarsOn()
+        self.reader.ReadAllColorScalarsOn()
+        self.reader.ReadAllNormalsOn()
+        self.reader.ReadAllTCoordsOn()
+        self.reader.ReadAllVectorsOn()
+        self.reader.ReadAllFieldsOn()
+        self.reader.ReadAllTensorsOn()
+
 
 class VTKPDataSetReader(BaseReader):
     """Parallel VTK Data Set Reader for .pvtk files."""
@@ -711,7 +937,7 @@ class VTKPDataSetReader(BaseReader):
 
 class BYUReader(BaseReader):
     """BYU Reader for .g files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -730,7 +956,7 @@ class BYUReader(BaseReader):
 
 class FacetReader(BaseReader):
     """Facet Reader for .facet files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -755,7 +981,7 @@ class Plot3DMetaReader(BaseReader):
 
 class BinaryMarchingCubesReader(BaseReader):
     """BinaryMarchingCubes Reader for .tri files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -785,7 +1011,7 @@ class PVDDataSet:
 # skip pydocstyle D102 check since docstring is taken from TimeReader
 class PVDReader(BaseReader, TimeReader):
     """PVD Reader for .pvd files.
-    
+
     Examples
     --------
     >>> import pyvista
@@ -815,11 +1041,11 @@ class PVDReader(BaseReader, TimeReader):
         self._time_values = []
 
         self._set_filename(filename)
-        
+
     @property
     def reader(self):
         """Return the PVDReader.
-        
+
         .. note::
             This Reader does not have an uderlying vtk Reader.
 
@@ -829,7 +1055,7 @@ class PVDReader(BaseReader, TimeReader):
     @property
     def active_readers(self):
         """Return the active readers.
-        
+
         Returns
         -------
         list[pyvista.BaseReader]
@@ -840,7 +1066,7 @@ class PVDReader(BaseReader, TimeReader):
     @property
     def datasets(self):
         """Return all datasets.
-        
+
         Returns
         -------
         list[pyvista.PVDDataSet]
@@ -851,7 +1077,7 @@ class PVDReader(BaseReader, TimeReader):
     @property
     def active_datasets(self):
         """Return all active datasets.
-        
+
         Returns
         -------
         list[pyvista.PVDDataSet]
@@ -918,7 +1144,7 @@ class PVDReader(BaseReader, TimeReader):
     @property
     def number_time_points(self):  # noqa: D102
         return len(self.time_values)
-    
+
     def time_point_value(self, time_point):  # noqa: D102
         return self.time_values[time_point]
 
